Os

Type Alias Os 

pub type Os = Os;
The name of the operating system which the image is built to run on. Validated values are listed in Go Language document for GOARCH

Aliased Type

pub enum Os {
Show 18 variants AIX, Android, Darwin, DragonFlyBSD, FreeBSD, Hurd, Illumos, iOS, Js, Linux, Nacl, NetBSD, OpenBSD, Plan9, Solaris, Windows, zOS, Other(String),
}

Variants



AIX



Android



Darwin



DragonFlyBSD



FreeBSD



Hurd



Illumos



iOS



Js



Linux



Nacl



NetBSD



OpenBSD



Plan9



Solaris



Windows



zOS



Other(String)