OciErrorCode

Enum OciErrorCode 

pub enum OciErrorCode {
Show 18 variants BlobUnknown, BlobUploadInvalid, BlobUploadUnknown, DigestInvalid, ManifestBlobUnknown, ManifestInvalid, ManifestUnknown, ManifestUnverified, NameInvalid, NameUnknown, NotFound, SizeInvalid, TagInvalid, Unauthorized, Denied, Unsupported, Toomanyrequests, Other(String),
}
OCI error codes

Outlined here

Variants



BlobUnknown

Blob unknown to registry

This error MAY be returned when a blob is unknown to the registry in a specified repository. This can be returned with a standard get or if a manifest references an unknown layer during upload.



BlobUploadInvalid

Blob upload is invalid

The blob upload encountered an error and can no longer proceed.



BlobUploadUnknown

Blob upload is unknown to registry



DigestInvalid

Provided digest did not match uploaded content.



ManifestBlobUnknown

Blob is unknown to registry



ManifestInvalid

Manifest is invalid

During upload, manifests undergo several checks ensuring validity. If those checks fail, this error MAY be returned, unless a more specific error is included. The detail will contain information the failed validation.



ManifestUnknown

Manifest unknown

This error is returned when the manifest, identified by name and tag is unknown to the repository.



ManifestUnverified

Manifest failed signature validation

DEPRECATED: This error code has been removed from the OCI spec.



NameInvalid

Invalid repository name



NameUnknown

Repository name is not known



NotFound

Manifest is not found



SizeInvalid

Provided length did not match content length



TagInvalid

Manifest tag did not match URI

DEPRECATED: This error code has been removed from the OCI spec.



Unauthorized

Authentication required.



Denied

Requested access to the resource is denied



Unsupported

This operation is unsupported



Toomanyrequests

Too many requests from client



Other(String)

An error code not defined by the OCI spec

Some registries return their own error codes. The original code is kept so that the rest of the error envelope can still be parsed.