pub struct TokenCache {
pub default_expiration_secs: usize,
/* private fields */
}Expand description
A cache to hold authentication tokens
Fields
default_expiration_secs: usizeDefault token expiration in seconds, to use when claim doesn’t specify a value
Implementations
Sourceimpl TokenCache
impl TokenCache
Sourcepub async fn insert(
&self,
reference: &Reference,
op: RegistryOperation,
token: RegistryTokenType,
)
pub async fn insert( &self, reference: &Reference, op: RegistryOperation, token: RegistryTokenType, )
Insert a token corresponding to reference and operation keys